@@ -3,7 +3,7 @@
 
 #
 # Generated  by generateDS.py.
-# Python 3.10.6 (main, Nov 14 2022, 16:10:14) [GCC 11.3.0]
+# Python 3.11.5 (main, Sep  2 2023, 14:16:33) [GCC 13.2.1 20230801]
 #
 # Command line options:
 #   ('--no-dates', '')
@@ -265,7 +265,11 @@ except ModulenotfoundExp_ as exp:
                     raise_parse_error(node, 'Requires sequence of integer values')
             return values
         def gds_format_float(self, input_data, input_name=''):
-            return ('%.15f' % float(input_data)).rstrip('0')
+            value = ('%.15f' % float(input_data)).rstrip('0')
+            if value.endswith('.'):
+                value += '0'
+            return value
+    
         def gds_parse_float(self, input_data, node=None, input_name=''):
             try:
                 fval_ = float(input_data)
@@ -1003,11 +1007,10 @@ def _cast(typ, value):
         return value
     return typ(value)
 
-#
-# Data representation classes.
-#
-
 
+#
+# Start enum classes
+#
 class oneperEnumType00_1(str, Enum):
     FLOAT='float'
     INT='int'
@@ -1022,6 +1025,9 @@ class oneperEnumType01_1(str, Enum):
     TOKEN='token'
 
 
+#
+# Start data representation classes
+#
 class oneperType01_1(GeneratedsSuper):
     __hash__ = GeneratedsSuper.__hash__
     member_data_items_ = [
@@ -1063,7 +1069,7 @@ class oneperType01_1(GeneratedsSuper):
         return self.inner01
     def set_inner01(self, inner01):
         self.inner01 = inner01
-    def _hasContent(self):
+    def has__content(self):
         if (
             self.username is not None or
             self.inner01 is not None
@@ -1087,7 +1093,7 @@ class oneperType01_1(GeneratedsSuper):
         outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
         already_processed = set()
         self._exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='oneperType01_1')
-        if self._hasContent():
+        if self.has__content():
             outfile.write('>%s' % (eol_, ))
             self._exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='oneperType01_1', pretty_print=pretty_print)
             showIndent(outfile, level, pretty_print)
@@ -1170,7 +1176,7 @@ class oneperType01_2(GeneratedsSuper):
         return self.userdescription
     def set_userdescription(self, userdescription):
         self.userdescription = userdescription
-    def _hasContent(self):
+    def has__content(self):
         if (
             self.userdescription is not None
         ):
@@ -1193,7 +1199,7 @@ class oneperType01_2(GeneratedsSuper):
         outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
         already_processed = set()
         self._exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='oneperType01_2')
-        if self._hasContent():
+        if self.has__content():
             outfile.write('>%s' % (eol_, ))
             self._exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='oneperType01_2', pretty_print=pretty_print)
             showIndent(outfile, level, pretty_print)
@@ -1234,6 +1240,11 @@ class oneperType01_2(GeneratedsSuper):
 # end class oneperType01_2
 
 
+#
+# End data representation classes.
+#
+
+
 GDSClassesMapping = {
     'root01': oneperType01_1,
 }
