@@ -3,7 +3,7 @@
 
 #
 # Generated  by generateDS.py.
-# Python 3.10.6 (main, Nov 14 2022, 16:10:14) [GCC 11.3.0]
+# Python 3.10.12 (main, Jun 11 2023, 05:26:28) [GCC 11.4.0]
 #
 # Command line options:
 #   ('--no-dates', '')
@@ -264,7 +264,11 @@ except ModulenotfoundExp_ as exp:
                     raise_parse_error(node, 'Requires sequence of integer values')
             return values
         def gds_format_float(self, input_data, input_name=''):
-            return ('%.15f' % float(input_data)).rstrip('0')
+            value = ('%.15f' % float(input_data)).rstrip('0')
+            if value.endswith('.'):
+                value += '0'
+            return value
+    
         def gds_parse_float(self, input_data, node=None, input_name=''):
             try:
                 fval_ = float(input_data)
@@ -1002,11 +1006,13 @@ def _cast(typ, value):
         return value
     return typ(value)
 
-#
-# Data representation classes.
-#
-
 
+#
+# Start enum classes
+#
+#
+# Start data representation classes
+#
 class document1Type(GeneratedsSuper):
     """document1Type --
     This is a element of Type 1.  It has some very nice documentation
@@ -1054,7 +1060,7 @@ class document1Type(GeneratedsSuper):
         return self.otherdoc
     def set_otherdoc(self, otherdoc):
         self.otherdoc = otherdoc
-    def _hasContent(self):
+    def has__content(self):
         if (
             self.comments is not None or
             self.otherdoc is not None
@@ -1078,7 +1084,7 @@ class document1Type(GeneratedsSuper):
         outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
         already_processed = set()
         self._exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='document1Type')
-        if self._hasContent():
+        if self.has__content():
             outfile.write('>%s' % (eol_, ))
             self._exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='document1Type', pretty_print=pretty_print)
             showIndent(outfile, level, pretty_print)
@@ -1181,7 +1187,7 @@ class document2Type(GeneratedsSuper):
         return self.anotherdoc
     def set_anotherdoc(self, anotherdoc):
         self.anotherdoc = anotherdoc
-    def _hasContent(self):
+    def has__content(self):
         if (
             self.comments is not None or
             self.rating is not None or
@@ -1206,7 +1212,7 @@ class document2Type(GeneratedsSuper):
         outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
         already_processed = set()
         self._exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='document2Type')
-        if self._hasContent():
+        if self.has__content():
             outfile.write('>%s' % (eol_, ))
             self._exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='document2Type', pretty_print=pretty_print)
             showIndent(outfile, level, pretty_print)
@@ -1310,7 +1316,7 @@ class document3Type(GeneratedsSuper):
         return self.rating
     def set_rating(self, rating):
         self.rating = rating
-    def _hasContent(self):
+    def has__content(self):
         if (
             self.comments is not None or
             self.rating is not None
@@ -1334,7 +1340,7 @@ class document3Type(GeneratedsSuper):
         outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
         already_processed = set()
         self._exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='document3Type')
-        if self._hasContent():
+        if self.has__content():
             outfile.write('>%s' % (eol_, ))
             self._exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='document3Type', pretty_print=pretty_print)
             showIndent(outfile, level, pretty_print)
@@ -1385,6 +1391,11 @@ class document3Type(GeneratedsSuper):
 # end class document3Type
 
 
+#
+# End data representation classes.
+#
+
+
 GDSClassesMapping = {
     'document1': document1Type,
 }
