@@ -3,7 +3,7 @@
 
 #
 # Generated  by generateDS.py.
-# Python 3.10.6 (main, Nov 14 2022, 16:10:14) [GCC 11.3.0]
+# Python 3.10.12 (main, Jun 11 2023, 05:26:28) [GCC 11.4.0]
 #
 # Command line options:
 #   ('--no-dates', '')
@@ -264,7 +264,11 @@ except ModulenotfoundExp_ as exp:
                     raise_parse_error(node, 'Requires sequence of integer values')
             return values
         def gds_format_float(self, input_data, input_name=''):
-            return ('%.15f' % float(input_data)).rstrip('0')
+            value = ('%.15f' % float(input_data)).rstrip('0')
+            if value.endswith('.'):
+                value += '0'
+            return value
+    
         def gds_parse_float(self, input_data, node=None, input_name=''):
             try:
                 fval_ = float(input_data)
@@ -1002,11 +1006,13 @@ def _cast(typ, value):
         return value
     return typ(value)
 
-#
-# Data representation classes.
-#
-
 
+#
+# Start enum classes
+#
+#
+# Start data representation classes
+#
 class PlantType_single(GeneratedsSuper):
     __hash__ = GeneratedsSuper.__hash__
     member_data_items_ = [
@@ -1052,7 +1058,7 @@ class PlantType_single(GeneratedsSuper):
         return self.description
     def set_description(self, description):
         self.description = description
-    def _hasContent(self):
+    def has__content(self):
         if (
             self.name is not None or
             self.anytypeobjs_ is not None or
@@ -1077,7 +1083,7 @@ class PlantType_single(GeneratedsSuper):
         outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
         already_processed = set()
         self._exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='PlantType_single')
-        if self._hasContent():
+        if self.has__content():
             outfile.write('>%s' % (eol_, ))
             self._exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='PlantType_single', pretty_print=pretty_print)
             showIndent(outfile, level, pretty_print)
@@ -1183,7 +1189,7 @@ class PlantType_multiple(GeneratedsSuper):
         return self.description
     def set_description(self, description):
         self.description = description
-    def _hasContent(self):
+    def has__content(self):
         if (
             self.name is not None or
             self.anytypeobjs_ or
@@ -1208,7 +1214,7 @@ class PlantType_multiple(GeneratedsSuper):
         outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
         already_processed = set()
         self._exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='PlantType_multiple')
-        if self._hasContent():
+        if self.has__content():
             outfile.write('>%s' % (eol_, ))
             self._exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='PlantType_multiple', pretty_print=pretty_print)
             showIndent(outfile, level, pretty_print)
@@ -1309,7 +1315,7 @@ class DescriptionType(GeneratedsSuper):
         return self.size
     def set_size(self, size):
         self.size = size
-    def _hasContent(self):
+    def has__content(self):
         if (
             self.name is not None or
             self.size is not None
@@ -1333,7 +1339,7 @@ class DescriptionType(GeneratedsSuper):
         outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
         already_processed = set()
         self._exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='DescriptionType')
-        if self._hasContent():
+        if self.has__content():
             outfile.write('>%s' % (eol_, ))
             self._exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='DescriptionType', pretty_print=pretty_print)
             showIndent(outfile, level, pretty_print)
@@ -1428,7 +1434,7 @@ class CatalogType(GeneratedsSuper):
         return self.catagory
     def set_catagory(self, catagory):
         self.catagory = catagory
-    def _hasContent(self):
+    def has__content(self):
         if (
             self.name is not None or
             self.catagory is not None
@@ -1452,7 +1458,7 @@ class CatalogType(GeneratedsSuper):
         outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
         already_processed = set()
         self._exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='CatalogType')
-        if self._hasContent():
+        if self.has__content():
             outfile.write('>%s' % (eol_, ))
             self._exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='CatalogType', pretty_print=pretty_print)
             showIndent(outfile, level, pretty_print)
@@ -1534,7 +1540,7 @@ class PlantType_single_nochild(GeneratedsSuper):
         self.ns_prefix_ = ns_prefix
     def get_anytypeobjs_(self): return self.anytypeobjs_
     def set_anytypeobjs_(self, anytypeobjs_): self.anytypeobjs_ = anytypeobjs_
-    def _hasContent(self):
+    def has__content(self):
         if (
             self.anytypeobjs_ is not None
         ):
@@ -1557,7 +1563,7 @@ class PlantType_single_nochild(GeneratedsSuper):
         outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
         already_processed = set()
         self._exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='PlantType_single_nochild')
-        if self._hasContent():
+        if self.has__content():
             outfile.write('>%s' % (eol_, ))
             self._exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='PlantType_single_nochild', pretty_print=pretty_print)
             showIndent(outfile, level, pretty_print)
@@ -1630,7 +1636,7 @@ class PlantType_multiple_nochild(GeneratedsSuper):
     def set_anytypeobjs_(self, anytypeobjs_): self.anytypeobjs_ = anytypeobjs_
     def add_anytypeobjs_(self, value): self.anytypeobjs_.append(value)
     def insert_anytypeobjs_(self, index, value): self._anytypeobjs_[index] = value
-    def _hasContent(self):
+    def has__content(self):
         if (
             self.anytypeobjs_
         ):
@@ -1653,7 +1659,7 @@ class PlantType_multiple_nochild(GeneratedsSuper):
         outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
         already_processed = set()
         self._exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='PlantType_multiple_nochild')
-        if self._hasContent():
+        if self.has__content():
             outfile.write('>%s' % (eol_, ))
             self._exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='PlantType_multiple_nochild', pretty_print=pretty_print)
             showIndent(outfile, level, pretty_print)
@@ -1691,6 +1697,11 @@ class PlantType_multiple_nochild(GeneratedsSuper):
 # end class PlantType_multiple_nochild
 
 
+#
+# End data representation classes.
+#
+
+
 GDSClassesMapping = {
 }
 
