@@ -3,7 +3,7 @@
 
 #
 # Generated  by generateDS.py.
-# Python 3.10.6 (main, Nov 14 2022, 16:10:14) [GCC 11.3.0]
+# Python 3.10.12 (main, Jun 11 2023, 05:26:28) [GCC 11.4.0]
 #
 # Command line options:
 #   ('--no-dates', '')
@@ -267,7 +267,11 @@ class GeneratedsSuper(object):
                 raise_parse_error(node, 'Requires sequence of integer values')
         return values
     def gds_format_float(self, input_data, input_name=''):
-        return ('%.15f' % float(input_data)).rstrip('0')
+        value = ('%.15f' % float(input_data)).rstrip('0')
+        if value.endswith('.'):
+            value += '0'
+        return value
+
     def gds_parse_float(self, input_data, node=None, input_name=''):
         try:
             fval_ = float(input_data)
@@ -1004,11 +1008,13 @@ def _cast(typ, value):
         return value
     return typ(value)
 
-#
-# Data representation classes.
-#
-
 
+#
+# Start enum classes
+#
+#
+# Start data representation classes
+#
 class myelement(GeneratedsSuper):
     __hash__ = GeneratedsSuper.__hash__
     member_data_items_ = {
@@ -1044,7 +1050,7 @@ class myelement(GeneratedsSuper):
         return self.href
     def set_href(self, href):
         self.href = href
-    def _hasContent(self):
+    def has__content(self):
         if (
 
         ):
@@ -1067,7 +1073,7 @@ class myelement(GeneratedsSuper):
         outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
         already_processed = set()
         self._exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='myelement')
-        if self._hasContent():
+        if self.has__content():
             outfile.write('>%s' % (eol_, ))
             self._exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='myelement', pretty_print=pretty_print)
             outfile.write('</%s%s>%s' % (namespaceprefix_, name_, eol_))
@@ -1100,6 +1106,11 @@ class myelement(GeneratedsSuper):
 # end class myelement
 
 
+#
+# End data representation classes.
+#
+
+
 GDSClassesMapping = {
 }
 
