@@ -97,6 +97,8 @@ $commands = [
   "diff -u recursive_generator_method1_sup.py recursive_generator_method2_sup.py",
   "diff -u recursive_generator_method1_sub.py recursive_generator_method2_sub.py",
   "diff -u episodic_second2.py episodic_second.py",
+  "diff -u people_graphql1.py people_graphql2.py",
+  "diff -u type_substitution1.py type_substitution2.py",
 ]
 
 def check
