@@ -3,7 +3,7 @@
 
 #
 # Generated  by generateDS.py.
-# Python 3.10.6 (main, Nov 14 2022, 16:10:14) [GCC 11.3.0]
+# Python 3.10.12 (main, Jun 11 2023, 05:26:28) [GCC 11.4.0]
 #
 # Command line options:
 #   ('--no-dates', '')
@@ -265,7 +265,11 @@ except ModulenotfoundExp_ as exp:
                     raise_parse_error(node, 'Requires sequence of integer values')
             return values
         def gds_format_float(self, input_data, input_name=''):
-            return ('%.15f' % float(input_data)).rstrip('0')
+            value = ('%.15f' % float(input_data)).rstrip('0')
+            if value.endswith('.'):
+                value += '0'
+            return value
+    
         def gds_parse_float(self, input_data, node=None, input_name=''):
             try:
                 fval_ = float(input_data)
@@ -1003,11 +1007,13 @@ def _cast(typ, value):
         return value
     return typ(value)
 
-#
-# Data representation classes.
-#
-
 
+#
+# Start enum classes
+#
+#
+# Start data representation classes
+#
 class dataKind(GeneratedsSuper):
     __hash__ = GeneratedsSuper.__hash__
     member_data_items_ = [
@@ -1070,7 +1076,7 @@ class dataKind(GeneratedsSuper):
         return self.data5
     def set_data5(self, data5):
         self.data5 = data5
-    def _hasContent(self):
+    def has__content(self):
         if (
             self.data1 is not None or
             self.data2 is not None or
@@ -1097,7 +1103,7 @@ class dataKind(GeneratedsSuper):
         outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
         already_processed = set()
         self._exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='dataType')
-        if self._hasContent():
+        if self.has__content():
             outfile.write('>%s' % (eol_, ))
             self._exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='dataType', pretty_print=pretty_print)
             showIndent(outfile, level, pretty_print)
@@ -1202,7 +1208,7 @@ class data1Kind(GeneratedsSuper):
         return self.content1
     def set_content1(self, content1):
         self.content1 = content1
-    def _hasContent(self):
+    def has__content(self):
         if (
             self.content1 is not None
         ):
@@ -1225,7 +1231,7 @@ class data1Kind(GeneratedsSuper):
         outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
         already_processed = set()
         self._exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='data1Type')
-        if self._hasContent():
+        if self.has__content():
             outfile.write('>%s' % (eol_, ))
             self._exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='data1Type', pretty_print=pretty_print)
             showIndent(outfile, level, pretty_print)
@@ -1300,7 +1306,7 @@ class MlassData2(GeneratedsSuper):
         return self.content1
     def set_content1(self, content1):
         self.content1 = content1
-    def _hasContent(self):
+    def has__content(self):
         if (
             self.content1 is not None
         ):
@@ -1323,7 +1329,7 @@ class MlassData2(GeneratedsSuper):
         outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
         already_processed = set()
         self._exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='TypeData2')
-        if self._hasContent():
+        if self.has__content():
             outfile.write('>%s' % (eol_, ))
             self._exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='TypeData2', pretty_print=pretty_print)
             showIndent(outfile, level, pretty_print)
@@ -1398,7 +1404,7 @@ class RealTypeData3(GeneratedsSuper):
         return self.content1
     def set_content1(self, content1):
         self.content1 = content1
-    def _hasContent(self):
+    def has__content(self):
         if (
             self.content1 is not None
         ):
@@ -1421,7 +1427,7 @@ class RealTypeData3(GeneratedsSuper):
         outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
         already_processed = set()
         self._exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='RealTypeData3')
-        if self._hasContent():
+        if self.has__content():
             outfile.write('>%s' % (eol_, ))
             self._exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='RealTypeData3', pretty_print=pretty_print)
             showIndent(outfile, level, pretty_print)
@@ -1496,7 +1502,7 @@ class MMMMMMdataKind(GeneratedsSuper):
         return self.content1
     def set_content1(self, content1):
         self.content1 = content1
-    def _hasContent(self):
+    def has__content(self):
         if (
             self.content1 is not None
         ):
@@ -1519,7 +1525,7 @@ class MMMMMMdataKind(GeneratedsSuper):
         outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
         already_processed = set()
         self._exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='AABBCCdataType')
-        if self._hasContent():
+        if self.has__content():
             outfile.write('>%s' % (eol_, ))
             self._exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='AABBCCdataType', pretty_print=pretty_print)
             showIndent(outfile, level, pretty_print)
@@ -1594,7 +1600,7 @@ class dataTypeNNNMNNN(GeneratedsSuper):
         return self.content1
     def set_content1(self, content1):
         self.content1 = content1
-    def _hasContent(self):
+    def has__content(self):
         if (
             self.content1 is not None
         ):
@@ -1617,7 +1623,7 @@ class dataTypeNNNMNNN(GeneratedsSuper):
         outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
         already_processed = set()
         self._exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='dataTypeXYZAXYZ')
-        if self._hasContent():
+        if self.has__content():
             outfile.write('>%s' % (eol_, ))
             self._exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='dataTypeXYZAXYZ', pretty_print=pretty_print)
             showIndent(outfile, level, pretty_print)
@@ -1658,6 +1664,11 @@ class dataTypeNNNMNNN(GeneratedsSuper):
 # end class dataTypeNNNMNNN
 
 
+#
+# End data representation classes.
+#
+
+
 GDSClassesMapping = {
     'data': dataKind,
 }
