@@ -3,7 +3,7 @@
 
 #
 # Generated  by generateDS.py.
-# Python 3.10.6 (main, Nov 14 2022, 16:10:14) [GCC 11.3.0]
+# Python 3.10.12 (main, Jun 11 2023, 05:26:28) [GCC 11.4.0]
 #
 # Command line options:
 #   ('--no-dates', '')
@@ -263,7 +263,11 @@ except ModulenotfoundExp_ as exp:
                     raise_parse_error(node, 'Requires sequence of integer values')
             return values
         def gds_format_float(self, input_data, input_name=''):
-            return ('%.15f' % float(input_data)).rstrip('0')
+            value = ('%.15f' % float(input_data)).rstrip('0')
+            if value.endswith('.'):
+                value += '0'
+            return value
+    
         def gds_parse_float(self, input_data, node=None, input_name=''):
             try:
                 fval_ = float(input_data)
@@ -1001,11 +1005,13 @@ def _cast(typ, value):
         return value
     return typ(value)
 
-#
-# Data representation classes.
-#
-
 
+#
+# Start enum classes
+#
+#
+# Start data representation classes
+#
 class DefaultTypes(GeneratedsSuper):
     __hash__ = GeneratedsSuper.__hash__
     member_data_items_ = [
@@ -1097,7 +1103,7 @@ class DefaultTypes(GeneratedsSuper):
         self.fixed2.insert(index, value)
     def replace_fixed2_at(self, index, value):
         self.fixed2[index] = value
-    def _hasContent(self):
+    def has__content(self):
         if (
             self.default1 or
             self.default2 or
@@ -1123,7 +1129,7 @@ class DefaultTypes(GeneratedsSuper):
         outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
         already_processed = set()
         self._exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='DefaultTypes')
-        if self._hasContent():
+        if self.has__content():
             outfile.write('>%s' % (eol_, ))
             self._exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='DefaultTypes', pretty_print=pretty_print)
             showIndent(outfile, level, pretty_print)
@@ -1269,7 +1275,7 @@ class DefaultType1(GeneratedsSuper):
         return self.default04
     def set_default04(self, default04):
         self.default04 = default04
-    def _hasContent(self):
+    def has__content(self):
         if (
             self.normal01 is not None or
             self.normal02 is not None or
@@ -1299,7 +1305,7 @@ class DefaultType1(GeneratedsSuper):
         outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
         already_processed = set()
         self._exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='DefaultType1')
-        if self._hasContent():
+        if self.has__content():
             outfile.write('>%s' % (eol_, ))
             self._exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='DefaultType1', pretty_print=pretty_print)
             showIndent(outfile, level, pretty_print)
@@ -1473,7 +1479,7 @@ class DefaultType2(GeneratedsSuper):
         return self.attrnormal02
     def set_attrnormal02(self, attrnormal02):
         self.attrnormal02 = attrnormal02
-    def _hasContent(self):
+    def has__content(self):
         if (
 
         ):
@@ -1496,7 +1502,7 @@ class DefaultType2(GeneratedsSuper):
         outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
         already_processed = set()
         self._exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='DefaultType2')
-        if self._hasContent():
+        if self.has__content():
             outfile.write('>%s' % (eol_, ))
             self._exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='DefaultType2', pretty_print=pretty_print)
             outfile.write('</%s%s>%s' % (namespaceprefix_, name_, eol_))
@@ -1633,7 +1639,7 @@ class FixedType1(GeneratedsSuper):
         return self.fixed04
     def set_fixed04(self, fixed04):
         self.fixed04 = fixed04
-    def _hasContent(self):
+    def has__content(self):
         if (
             self.normal01 is not None or
             self.normal02 is not None or
@@ -1663,7 +1669,7 @@ class FixedType1(GeneratedsSuper):
         outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
         already_processed = set()
         self._exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='FixedType1')
-        if self._hasContent():
+        if self.has__content():
             outfile.write('>%s' % (eol_, ))
             self._exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='FixedType1', pretty_print=pretty_print)
             showIndent(outfile, level, pretty_print)
@@ -1829,7 +1835,7 @@ class FixedType2(GeneratedsSuper):
         return self.attrnormal02
     def set_attrnormal02(self, attrnormal02):
         self.attrnormal02 = attrnormal02
-    def _hasContent(self):
+    def has__content(self):
         if (
 
         ):
@@ -1852,7 +1858,7 @@ class FixedType2(GeneratedsSuper):
         outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
         already_processed = set()
         self._exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='FixedType2')
-        if self._hasContent():
+        if self.has__content():
             outfile.write('>%s' % (eol_, ))
             self._exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='FixedType2', pretty_print=pretty_print)
             outfile.write('</%s%s>%s' % (namespaceprefix_, name_, eol_))
@@ -1906,6 +1912,11 @@ class FixedType2(GeneratedsSuper):
 # end class FixedType2
 
 
+#
+# End data representation classes.
+#
+
+
 GDSClassesMapping = {
     'defaults': DefaultTypes,
 }
