@@ -3,7 +3,7 @@
 
 #
 # Generated  by generateDS.py.
-# Python 3.10.6 (main, Nov 14 2022, 16:10:14) [GCC 11.3.0]
+# Python 3.10.12 (main, Jun 11 2023, 05:26:28) [GCC 11.4.0]
 #
 # Command line options:
 #   ('--no-dates', '')
@@ -264,7 +264,11 @@ except ModulenotfoundExp_ as exp:
                     raise_parse_error(node, 'Requires sequence of integer values')
             return values
         def gds_format_float(self, input_data, input_name=''):
-            return ('%.15f' % float(input_data)).rstrip('0')
+            value = ('%.15f' % float(input_data)).rstrip('0')
+            if value.endswith('.'):
+                value += '0'
+            return value
+    
         def gds_parse_float(self, input_data, node=None, input_name=''):
             try:
                 fval_ = float(input_data)
@@ -1002,11 +1006,13 @@ def _cast(typ, value):
         return value
     return typ(value)
 
-#
-# Data representation classes.
-#
-
 
+#
+# Start enum classes
+#
+#
+# Start data representation classes
+#
 class DefaultTypes(GeneratedsSuper):
     __hash__ = GeneratedsSuper.__hash__
     member_data_items_ = [
@@ -1048,7 +1054,7 @@ class DefaultTypes(GeneratedsSuper):
         return self.default2
     def set_default2(self, default2):
         self.default2 = default2
-    def _hasContent(self):
+    def has__content(self):
         if (
             self.default1 is not None or
             self.default2 is not None
@@ -1072,7 +1078,7 @@ class DefaultTypes(GeneratedsSuper):
         outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
         already_processed = set()
         self._exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='DefaultTypes')
-        if self._hasContent():
+        if self.has__content():
             outfile.write('>%s' % (eol_, ))
             self._exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='DefaultTypes', pretty_print=pretty_print)
             showIndent(outfile, level, pretty_print)
@@ -1289,7 +1295,7 @@ class DefaultType1(GeneratedsSuper):
         return self.normal08
     def set_normal08(self, normal08):
         self.normal08 = normal08
-    def _hasContent(self):
+    def has__content(self):
         if (
             self.default01 != 23 or
             self.normal01 is not None or
@@ -1328,7 +1334,7 @@ class DefaultType1(GeneratedsSuper):
         outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
         already_processed = set()
         self._exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='DefaultType1')
-        if self._hasContent():
+        if self.has__content():
             outfile.write('>%s' % (eol_, ))
             self._exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='DefaultType1', pretty_print=pretty_print)
             showIndent(outfile, level, pretty_print)
@@ -1693,7 +1699,7 @@ class DefaultType2(GeneratedsSuper):
         return self.normal08
     def set_normal08(self, normal08):
         self.normal08 = normal08
-    def _hasContent(self):
+    def has__content(self):
         if (
             self.default01 != 23 or
             self.normal01 is not None or
@@ -1732,7 +1738,7 @@ class DefaultType2(GeneratedsSuper):
         outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
         already_processed = set()
         self._exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='DefaultType2')
-        if self._hasContent():
+        if self.has__content():
             outfile.write('>%s' % (eol_, ))
             self._exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='DefaultType2', pretty_print=pretty_print)
             showIndent(outfile, level, pretty_print)
@@ -1963,6 +1969,11 @@ class DefaultType2(GeneratedsSuper):
 # end class DefaultType2
 
 
+#
+# End data representation classes.
+#
+
+
 GDSClassesMapping = {
     'defaults': DefaultTypes,
 }
