@@ -3,7 +3,7 @@
 
 #
 # Generated  by generateDS.py.
-# Python 3.10.6 (main, Nov 14 2022, 16:10:14) [GCC 11.3.0]
+# Python 3.10.12 (main, Jun 11 2023, 05:26:28) [GCC 11.4.0]
 #
 # Command line options:
 #   ('--no-dates', '')
@@ -264,7 +264,11 @@ except ModulenotfoundExp_ as exp:
                     raise_parse_error(node, 'Requires sequence of integer values')
             return values
         def gds_format_float(self, input_data, input_name=''):
-            return ('%.15f' % float(input_data)).rstrip('0')
+            value = ('%.15f' % float(input_data)).rstrip('0')
+            if value.endswith('.'):
+                value += '0'
+            return value
+    
         def gds_parse_float(self, input_data, node=None, input_name=''):
             try:
                 fval_ = float(input_data)
@@ -1002,11 +1006,13 @@ def _cast(typ, value):
         return value
     return typ(value)
 
-#
-# Data representation classes.
-#
-
 
+#
+# Start enum classes
+#
+#
+# Start data representation classes
+#
 class animalCollection(GeneratedsSuper):
     __hash__ = GeneratedsSuper.__hash__
     member_data_items_ = [
@@ -1058,7 +1064,7 @@ class animalCollection(GeneratedsSuper):
         self.animal.insert(index, value)
     def replace_animal_at(self, index, value):
         self.animal[index] = value
-    def _hasContent(self):
+    def has__content(self):
         if (
             self.animal
         ):
@@ -1081,7 +1087,7 @@ class animalCollection(GeneratedsSuper):
         outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
         already_processed = set()
         self._exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='animalCollection')
-        if self._hasContent():
+        if self.has__content():
             outfile.write('>%s' % (eol_, ))
             self._exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='animalCollection', pretty_print=pretty_print)
             showIndent(outfile, level, pretty_print)
@@ -1163,7 +1169,7 @@ class animal(GeneratedsSuper):
         self.ns_prefix_ = ns_prefix
     def get_extensiontype_(self): return self.extensiontype_
     def set_extensiontype_(self, extensiontype_): self.extensiontype_ = extensiontype_
-    def _hasContent(self):
+    def has__content(self):
         if (
 
         ):
@@ -1186,7 +1192,7 @@ class animal(GeneratedsSuper):
         outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
         already_processed = set()
         self._exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='animal')
-        if self._hasContent():
+        if self.has__content():
             outfile.write('>%s' % (eol_, ))
             self._exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='animal', pretty_print=pretty_print)
             outfile.write('</%s%s>%s' % (namespaceprefix_, name_, eol_))
@@ -1260,10 +1266,10 @@ class dog(animal):
         return self.name
     def set_name(self, name):
         self.name = name
-    def _hasContent(self):
+    def has__content(self):
         if (
             self.name is not None or
-            super(dog, self)._hasContent()
+            super(dog, self).has__content()
         ):
             return True
         else:
@@ -1284,7 +1290,7 @@ class dog(animal):
         outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
         already_processed = set()
         self._exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='dog')
-        if self._hasContent():
+        if self.has__content():
             outfile.write('>%s' % (eol_, ))
             self._exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='dog', pretty_print=pretty_print)
             showIndent(outfile, level, pretty_print)
@@ -1327,6 +1333,11 @@ class dog(animal):
 # end class dog
 
 
+#
+# End data representation classes.
+#
+
+
 GDSClassesMapping = {
 }
 
