@@ -3,7 +3,7 @@
 
 #
 # Generated  by generateDS.py.
-# Python 3.10.6 (main, Nov 14 2022, 16:10:14) [GCC 11.3.0]
+# Python 3.10.12 (main, Jun 11 2023, 05:26:28) [GCC 11.4.0]
 #
 # Command line options:
 #   ('--no-dates', '')
@@ -259,7 +259,11 @@ class GeneratedsSuper(object):
                 raise_parse_error(node, 'Requires sequence of integer values')
         return values
     def gds_format_float(self, input_data, input_name=''):
-        return ('%.15f' % float(input_data)).rstrip('0')
+        value = ('%.15f' % float(input_data)).rstrip('0')
+        if value.endswith('.'):
+            value += '0'
+        return value
+
     def gds_parse_float(self, input_data, node=None, input_name=''):
         try:
             fval_ = float(input_data)
@@ -997,11 +1001,13 @@ def _cast(typ, value):
         return value
     return typ(value)
 
-#
-# Data representation classes.
-#
-
 
+#
+# Start enum classes
+#
+#
+# Start data representation classes
+#
 class PackageType(GeneratedsSuper):
     __hash__ = GeneratedsSuper.__hash__
     member_data_items_ = [
@@ -1036,7 +1042,7 @@ class PackageType(GeneratedsSuper):
         self.Address.insert(index, value)
     def replace_Address_at(self, index, value):
         self.Address[index] = value
-    def _hasContent(self):
+    def has__content(self):
         if (
             self.Address
         ):
@@ -1046,6 +1052,11 @@ class PackageType(GeneratedsSuper):
 # end class PackageType
 
 
+#
+# End data representation classes.
+#
+
+
 GDSClassesMapping = {
     'Package': PackageType,
 }
