@@ -3,7 +3,7 @@
 
 #
 # Generated  by generateDS.py.
-# Python 3.10.6 (main, Nov 14 2022, 16:10:14) [GCC 11.3.0]
+# Python 3.11.5 (main, Sep  2 2023, 14:16:33) [GCC 13.2.1 20230801]
 #
 # Command line options:
 #   ('--no-dates', '')
@@ -265,7 +265,11 @@ except ModulenotfoundExp_ as exp:
                     raise_parse_error(node, 'Requires sequence of integer values')
             return values
         def gds_format_float(self, input_data, input_name=''):
-            return ('%.15f' % float(input_data)).rstrip('0')
+            value = ('%.15f' % float(input_data)).rstrip('0')
+            if value.endswith('.'):
+                value += '0'
+            return value
+    
         def gds_parse_float(self, input_data, node=None, input_name=''):
             try:
                 fval_ = float(input_data)
@@ -1003,12 +1007,14 @@ def _cast(typ, value):
         return value
     return typ(value)
 
-#
-# Data representation classes.
-#
-
 from foo.bar.episodic_first import Type01_1
 
+#
+# Start enum classes
+#
+#
+# Start data representation classes
+#
 class Type02_1(GeneratedsSuper):
     __hash__ = GeneratedsSuper.__hash__
     member_data_items_ = {
@@ -1050,7 +1056,7 @@ class Type02_1(GeneratedsSuper):
         return self.inner01
     def set_inner01(self, inner01):
         self.inner01 = inner01
-    def _hasContent(self):
+    def has__content(self):
         if (
             self.username is not None or
             self.inner01 is not None
@@ -1074,7 +1080,7 @@ class Type02_1(GeneratedsSuper):
         outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
         already_processed = set()
         self._exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='Type02_1')
-        if self._hasContent():
+        if self.has__content():
             outfile.write('>%s' % (eol_, ))
             self._exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='Type02_1', pretty_print=pretty_print)
             showIndent(outfile, level, pretty_print)
@@ -1123,6 +1129,11 @@ class Type02_1(GeneratedsSuper):
 # end class Type02_1
 
 
+#
+# End data representation classes.
+#
+
+
 GDSClassesMapping = {
 }
 
