@@ -1287,6 +1287,86 @@ class GenTest(unittest.TestCase):
         # cleanup generated files
         #self.remove('{}.py'.format(t_))
 
+    def test_050_graphql_server(self):
+        cmdTempl = (
+            'python3 generateDS.py --no-dates --no-versions '
+            '--silence --member-specs=dict -f '
+            '--graphql="people:people" '
+            '-o tests/%s_graphql2.py '
+            'tests/%s.xsd'
+        )
+        t_ = 'people'
+        cmd = cmdTempl % (t_, t_, )
+        self.executeClean(cmd)
+        self.compareFiles(
+            '{}_graphql1.py'.format(t_),
+            '{}_graphql2.py'.format(t_),
+            ('sys.stdout.write',))
+        self.compareFiles('{}_graphql1.py'.format(t_), '{}_graphql2.py'.format(t_))
+        # cleanup generated files
+        #self.remove('{}2_sup.py'.format(t_))
+        #self.remove('{}2_sub.py'.format(t_))
+
+    def test_051_split_join(self):
+        cmdTempl = (
+            'python3 generateDS.py --no-dates --no-versions '
+            '--silence --member-specs=dict -f '
+            '-o tests/%s2.py '
+            'tests/%s.xsd'
+        )
+        t_ = 'split_join'
+        cmd = cmdTempl % (t_, t_, )
+        # print('1. debug:', cmd)
+        self.executeClean(cmd)
+        cmdTempl = (
+            'python3 utils/gds_split_one_to_many.py '
+            '--force '
+            'tests/%s2.py tests/%s_dir'
+        )
+        cmd = cmdTempl % (t_, t_, )
+        # print('2. debug:', cmd)
+        self.executeClean(cmd)
+        cmdTempl = (
+            'python3 utils/gds_join_many_to_one.py '
+            '--force '
+            'tests/%s_dir tests/%s2a.py'
+        )
+        cmd = cmdTempl % (t_, t_, )
+        # print('3. debug:', cmd)
+        self.executeClean(cmd)
+        self.compareFiles('{}1.py'.format(t_), '{}2.py'.format(t_))
+        self.compareFiles('{}2.py'.format(t_), '{}2a.py'.format(t_))
+        # cleanup generated files
+        #self.remove('{}2_sup.py'.format(t_))
+        #self.remove('{}2_sub.py'.format(t_))
+
+    def test_052_type_substitution(self):
+        cmdTempl = (
+            'python3 generateDS.py --no-dates --no-versions '
+            '--member-specs=list -f '
+            '-o tests/%s2_sup.py -s tests/%s2_sub.py '
+            '--super=%s2_sup '
+            '--always-export-default '
+            '--preserve-cdata-tags '
+            'tests/%s.xsd'
+        )
+        t_ = 'type_substitution'
+        cmd = cmdTempl % (t_, t_, t_, t_, )
+        self.executeClean(cmd)
+        self.compareFiles(
+            '{}1_sup.py'.format(t_),
+            '{}2_sup.py'.format(t_),
+            ('sys.stdout.write',))
+        self.compareFiles('{}1_sub.py'.format(t_), '{}2_sub.py'.format(t_))
+        cmdTempl = 'python3 tests/%s2_sup.py tests/%s.xml > tests/%s2_out.xml'
+        cmd = cmdTempl % (t_, t_, t_, )
+        self.executeClean(cmd)
+        self.compareFiles('{}1_out.xml'.format(t_), '{}2_out.xml'.format(t_))
+        # cleanup generated files
+        self.remove('{}2_sup.py'.format(t_))
+        self.remove('{}2_sub.py'.format(t_))
+        self.remove('{}2_out.xml'.format(t_))
+
     def compareFiles(self, left, right, ignore=None):
         left = os.path.join(TEST_DIR, left)
         right = os.path.join(TEST_DIR, right)
