@@ -3,7 +3,7 @@
 
 #
 # Generated  by generateDS.py.
-# Python 3.10.6 (main, Nov 14 2022, 16:10:14) [GCC 11.3.0]
+# Python 3.10.12 (main, Jun 11 2023, 05:26:28) [GCC 11.4.0]
 #
 # Command line options:
 #   ('--no-dates', '')
@@ -263,7 +263,11 @@ except ModulenotfoundExp_ as exp:
                     raise_parse_error(node, 'Requires sequence of integer values')
             return values
         def gds_format_float(self, input_data, input_name=''):
-            return ('%.15f' % float(input_data)).rstrip('0')
+            value = ('%.15f' % float(input_data)).rstrip('0')
+            if value.endswith('.'):
+                value += '0'
+            return value
+    
         def gds_parse_float(self, input_data, node=None, input_name=''):
             try:
                 fval_ = float(input_data)
@@ -1001,11 +1005,10 @@ def _cast(typ, value):
         return value
     return typ(value)
 
-#
-# Data representation classes.
-#
-
 
+#
+# Start enum classes
+#
 class USState(str, Enum):
     AK='AK'
     AL='AL'
@@ -1013,6 +1016,9 @@ class USState(str, Enum):
     PA='PA'
 
 
+#
+# Start data representation classes
+#
 class PurchaseOrderType(GeneratedsSuper):
     __hash__ = GeneratedsSuper.__hash__
     member_data_items_ = [
@@ -1078,7 +1084,7 @@ class PurchaseOrderType(GeneratedsSuper):
         return self.orderDate
     def set_orderDate(self, orderDate):
         self.orderDate = orderDate
-    def _hasContent(self):
+    def has__content(self):
         if (
             self.shipTo is not None or
             self.billTo is not None or
@@ -1104,7 +1110,7 @@ class PurchaseOrderType(GeneratedsSuper):
         outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
         already_processed = set()
         self._exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='PurchaseOrderType')
-        if self._hasContent():
+        if self.has__content():
             outfile.write('>%s' % (eol_, ))
             self._exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='PurchaseOrderType', pretty_print=pretty_print)
             showIndent(outfile, level, pretty_print)
@@ -1222,7 +1228,7 @@ class Items(GeneratedsSuper):
         self.item.insert(index, value)
     def replace_item_at(self, index, value):
         self.item[index] = value
-    def _hasContent(self):
+    def has__content(self):
         if (
             self.item
         ):
@@ -1245,7 +1251,7 @@ class Items(GeneratedsSuper):
         outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
         already_processed = set()
         self._exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='Items')
-        if self._hasContent():
+        if self.has__content():
             outfile.write('>%s' % (eol_, ))
             self._exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='Items', pretty_print=pretty_print)
             showIndent(outfile, level, pretty_print)
@@ -1335,7 +1341,7 @@ class Address(GeneratedsSuper):
         self.city = city
     def get_extensiontype_(self): return self.extensiontype_
     def set_extensiontype_(self, extensiontype_): self.extensiontype_ = extensiontype_
-    def _hasContent(self):
+    def has__content(self):
         if (
             self.name is not None or
             self.street is not None or
@@ -1360,7 +1366,7 @@ class Address(GeneratedsSuper):
         outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
         already_processed = set()
         self._exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='Address')
-        if self._hasContent():
+        if self.has__content():
             outfile.write('>%s' % (eol_, ))
             self._exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='Address', pretty_print=pretty_print)
             showIndent(outfile, level, pretty_print)
@@ -1490,11 +1496,11 @@ class USAddress(Address):
                 self.gds_collector_.add_message('Value "%(value)s"%(lineno)s does not match xsd enumeration restriction on USState' % {"value" : encode_str_2_3(value), "lineno": lineno} )
                 result = False
         return result
-    def _hasContent(self):
+    def has__content(self):
         if (
             self.state is not None or
             self.zip is not None or
-            super(USAddress, self)._hasContent()
+            super(USAddress, self).has__content()
         ):
             return True
         else:
@@ -1515,7 +1521,7 @@ class USAddress(Address):
         outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
         already_processed = set()
         self._exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='USAddress')
-        if self._hasContent():
+        if self.has__content():
             outfile.write('>%s' % (eol_, ))
             self._exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='USAddress', pretty_print=pretty_print)
             showIndent(outfile, level, pretty_print)
@@ -1628,10 +1634,10 @@ class UKAddress(Address):
                 self.gds_collector_.add_message('Value "%(value)s"%(lineno)s does not match xsd maxLength restriction on UKPostcode' % {"value" : encode_str_2_3(value), "lineno": lineno} )
                 result = False
         return result
-    def _hasContent(self):
+    def has__content(self):
         if (
             self.postcode is not None or
-            super(UKAddress, self)._hasContent()
+            super(UKAddress, self).has__content()
         ):
             return True
         else:
@@ -1652,7 +1658,7 @@ class UKAddress(Address):
         outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
         already_processed = set()
         self._exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='UKAddress')
-        if self._hasContent():
+        if self.has__content():
             outfile.write('>%s' % (eol_, ))
             self._exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='UKAddress', pretty_print=pretty_print)
             showIndent(outfile, level, pretty_print)
@@ -1804,7 +1810,7 @@ class itemType(GeneratedsSuper):
                     self.validate_SKU_patterns_, value):
                 self.gds_collector_.add_message('Value "%s" does not match xsd pattern restrictions: %s' % (encode_str_2_3(value), self.validate_SKU_patterns_, ))
     validate_SKU_patterns_ = [['^(\\d{3}-[A-Z]{2})$']]
-    def _hasContent(self):
+    def has__content(self):
         if (
             self.productName is not None or
             self.quantity is not None or
@@ -1831,7 +1837,7 @@ class itemType(GeneratedsSuper):
         outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
         already_processed = set()
         self._exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='itemType')
-        if self._hasContent():
+        if self.has__content():
             outfile.write('>%s' % (eol_, ))
             self._exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='itemType', pretty_print=pretty_print)
             showIndent(outfile, level, pretty_print)
@@ -1921,6 +1927,11 @@ class itemType(GeneratedsSuper):
 # end class itemType
 
 
+#
+# End data representation classes.
+#
+
+
 GDSClassesMapping = {
     'purchaseOrder': PurchaseOrderType,
 }
