@@ -3,7 +3,7 @@
 
 #
 # Generated  by generateDS.py.
-# Python 3.10.6 (main, Nov 14 2022, 16:10:14) [GCC 11.3.0]
+# Python 3.10.12 (main, Jun 11 2023, 05:26:28) [GCC 11.4.0]
 #
 # Command line options:
 #   ('--no-dates', '')
@@ -263,7 +263,11 @@ except ModulenotfoundExp_ as exp:
                     raise_parse_error(node, 'Requires sequence of integer values')
             return values
         def gds_format_float(self, input_data, input_name=''):
-            return ('%.15f' % float(input_data)).rstrip('0')
+            value = ('%.15f' % float(input_data)).rstrip('0')
+            if value.endswith('.'):
+                value += '0'
+            return value
+    
         def gds_parse_float(self, input_data, node=None, input_name=''):
             try:
                 fval_ = float(input_data)
@@ -1001,11 +1005,13 @@ def _cast(typ, value):
         return value
     return typ(value)
 
-#
-# Data representation classes.
-#
-
 
+#
+# Start enum classes
+#
+#
+# Start data representation classes
+#
 class rootType(GeneratedsSuper):
     __hash__ = GeneratedsSuper.__hash__
     member_data_items_ = [
@@ -1049,7 +1055,7 @@ class rootType(GeneratedsSuper):
         self.markup.insert(index, value)
     def replace_markup_at(self, index, value):
         self.markup[index] = value
-    def _hasContent(self):
+    def has__content(self):
         if (
             self.markup
         ):
@@ -1072,7 +1078,7 @@ class rootType(GeneratedsSuper):
         outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
         already_processed = set()
         self._exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='rootType')
-        if self._hasContent():
+        if self.has__content():
             outfile.write('>%s' % (eol_, ))
             self._exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='rootType', pretty_print=pretty_print)
             showIndent(outfile, level, pretty_print)
@@ -1183,7 +1189,7 @@ class markupType(GeneratedsSuper):
         self.nested[index] = value
     def get_valueOf_(self): return self.valueOf_
     def set_valueOf_(self, valueOf_): self.valueOf_ = valueOf_
-    def _hasContent(self):
+    def has__content(self):
         if (
             self.embedded or
             self.nested or
@@ -1349,7 +1355,7 @@ class nestedType(GeneratedsSuper):
         self.nested3.insert(index, value)
     def replace_nested3_at(self, index, value):
         self.nested3[index] = value
-    def _hasContent(self):
+    def has__content(self):
         if (
             self.nested1 or
             self.nested2 or
@@ -1374,7 +1380,7 @@ class nestedType(GeneratedsSuper):
         outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
         already_processed = set()
         self._exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='nestedType')
-        if self._hasContent():
+        if self.has__content():
             outfile.write('>%s' % (eol_, ))
             self._exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='nestedType', pretty_print=pretty_print)
             showIndent(outfile, level, pretty_print)
@@ -1492,7 +1498,7 @@ class nested1Type(GeneratedsSuper):
         self.nestedA2.insert(index, value)
     def replace_nestedA2_at(self, index, value):
         self.nestedA2[index] = value
-    def _hasContent(self):
+    def has__content(self):
         if (
             self.nestedA1 or
             self.nestedA2
@@ -1516,7 +1522,7 @@ class nested1Type(GeneratedsSuper):
         outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
         already_processed = set()
         self._exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='nested1Type')
-        if self._hasContent():
+        if self.has__content():
             outfile.write('>%s' % (eol_, ))
             self._exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='nested1Type', pretty_print=pretty_print)
             showIndent(outfile, level, pretty_print)
@@ -1622,7 +1628,7 @@ class nested1AType(GeneratedsSuper):
         self.nestedB2.insert(index, value)
     def replace_nestedB2_at(self, index, value):
         self.nestedB2[index] = value
-    def _hasContent(self):
+    def has__content(self):
         if (
             self.nestedB1 or
             self.nestedB2
@@ -1646,7 +1652,7 @@ class nested1AType(GeneratedsSuper):
         outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
         already_processed = set()
         self._exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='nested1AType')
-        if self._hasContent():
+        if self.has__content():
             outfile.write('>%s' % (eol_, ))
             self._exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='nested1AType', pretty_print=pretty_print)
             showIndent(outfile, level, pretty_print)
@@ -1697,6 +1703,11 @@ class nested1AType(GeneratedsSuper):
 # end class nested1AType
 
 
+#
+# End data representation classes.
+#
+
+
 GDSClassesMapping = {
     'root': rootType,
 }
