@@ -3,7 +3,7 @@
 
 #
 # Generated  by generateDS.py.
-# Python 3.10.6 (main, Nov 14 2022, 16:10:14) [GCC 11.3.0]
+# Python 3.10.12 (main, Jun 11 2023, 05:26:28) [GCC 11.4.0]
 #
 # Command line options:
 #   ('--no-dates', '')
@@ -263,7 +263,11 @@ except ModulenotfoundExp_ as exp:
                     raise_parse_error(node, 'Requires sequence of integer values')
             return values
         def gds_format_float(self, input_data, input_name=''):
-            return ('%.15f' % float(input_data)).rstrip('0')
+            value = ('%.15f' % float(input_data)).rstrip('0')
+            if value.endswith('.'):
+                value += '0'
+            return value
+    
         def gds_parse_float(self, input_data, node=None, input_name=''):
             try:
                 fval_ = float(input_data)
@@ -1001,11 +1005,13 @@ def _cast(typ, value):
         return value
     return typ(value)
 
-#
-# Data representation classes.
-#
-
 
+#
+# Start enum classes
+#
+#
+# Start data representation classes
+#
 class containerType(GeneratedsSuper):
     __hash__ = GeneratedsSuper.__hash__
     member_data_items_ = [
@@ -1047,7 +1053,7 @@ class containerType(GeneratedsSuper):
         return self.item2
     def set_item2(self, item2):
         self.item2 = item2
-    def _hasContent(self):
+    def has__content(self):
         if (
             self.item1 is not None or
             self.item2 is not None
@@ -1071,7 +1077,7 @@ class containerType(GeneratedsSuper):
         outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
         already_processed = set()
         self._exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='containerType')
-        if self._hasContent():
+        if self.has__content():
             outfile.write('>%s' % (eol_, ))
             self._exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='containerType', pretty_print=pretty_print)
             showIndent(outfile, level, pretty_print)
@@ -1152,7 +1158,7 @@ class classAType(GeneratedsSuper):
         return self.inner
     def set_inner(self, inner):
         self.inner = inner
-    def _hasContent(self):
+    def has__content(self):
         if (
             self.inner is not None
         ):
@@ -1175,7 +1181,7 @@ class classAType(GeneratedsSuper):
         outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
         already_processed = set()
         self._exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='classAType')
-        if self._hasContent():
+        if self.has__content():
             outfile.write('>%s' % (eol_, ))
             self._exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='classAType', pretty_print=pretty_print)
             showIndent(outfile, level, pretty_print)
@@ -1248,7 +1254,7 @@ class classBType(GeneratedsSuper):
         return self.inner
     def set_inner(self, inner):
         self.inner = inner
-    def _hasContent(self):
+    def has__content(self):
         if (
             self.inner is not None
         ):
@@ -1271,7 +1277,7 @@ class classBType(GeneratedsSuper):
         outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
         already_processed = set()
         self._exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='classBType')
-        if self._hasContent():
+        if self.has__content():
             outfile.write('>%s' % (eol_, ))
             self._exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='classBType', pretty_print=pretty_print)
             showIndent(outfile, level, pretty_print)
@@ -1351,7 +1357,7 @@ class innerType(GeneratedsSuper):
         return self.attrA2
     def set_attrA2(self, attrA2):
         self.attrA2 = attrA2
-    def _hasContent(self):
+    def has__content(self):
         if (
 
         ):
@@ -1374,7 +1380,7 @@ class innerType(GeneratedsSuper):
         outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
         already_processed = set()
         self._exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='innerType')
-        if self._hasContent():
+        if self.has__content():
             outfile.write('>%s' % (eol_, ))
             self._exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='innerType', pretty_print=pretty_print)
             outfile.write('</%s%s>%s' % (namespaceprefix_, name_, eol_))
@@ -1455,7 +1461,7 @@ class innerType1(GeneratedsSuper):
         return self.attrB2
     def set_attrB2(self, attrB2):
         self.attrB2 = attrB2
-    def _hasContent(self):
+    def has__content(self):
         if (
 
         ):
@@ -1478,7 +1484,7 @@ class innerType1(GeneratedsSuper):
         outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
         already_processed = set()
         self._exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='innerType1')
-        if self._hasContent():
+        if self.has__content():
             outfile.write('>%s' % (eol_, ))
             self._exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='innerType1', pretty_print=pretty_print)
             outfile.write('</%s%s>%s' % (namespaceprefix_, name_, eol_))
@@ -1518,6 +1524,11 @@ class innerType1(GeneratedsSuper):
 # end class innerType1
 
 
+#
+# End data representation classes.
+#
+
+
 GDSClassesMapping = {
     'classA': classAType,
     'classB': classBType,
