@@ -3,7 +3,7 @@
 
 #
 # Generated  by generateDS.py.
-# Python 3.10.6 (main, Nov 14 2022, 16:10:14) [GCC 11.3.0]
+# Python 3.10.12 (main, Jun 11 2023, 05:26:28) [GCC 11.4.0]
 #
 # Command line options:
 #   ('--no-dates', '')
@@ -259,7 +259,11 @@ class GeneratedsSuper(object):
                 raise_parse_error(node, 'Requires sequence of integer values')
         return values
     def gds_format_float(self, input_data, input_name=''):
-        return ('%.15f' % float(input_data)).rstrip('0')
+        value = ('%.15f' % float(input_data)).rstrip('0')
+        if value.endswith('.'):
+            value += '0'
+        return value
+
     def gds_parse_float(self, input_data, node=None, input_name=''):
         try:
             fval_ = float(input_data)
@@ -997,11 +1001,13 @@ def _cast(typ, value):
         return value
     return typ(value)
 
-#
-# Data representation classes.
-#
-
 
+#
+# Start enum classes
+#
+#
+# Start data representation classes
+#
 class peopleType(GeneratedsSuper):
     __hash__ = GeneratedsSuper.__hash__
     member_data_items_ = [
@@ -1051,7 +1057,7 @@ class peopleType(GeneratedsSuper):
         self.specialperson.insert(index, value)
     def replace_specialperson_at(self, index, value):
         self.specialperson[index] = value
-    def _hasContent(self):
+    def has__content(self):
         if (
             self.person or
             self.specialperson
@@ -1132,7 +1138,7 @@ class personType(GeneratedsSuper):
         return self.ratio
     def set_ratio(self, ratio):
         self.ratio = ratio
-    def _hasContent(self):
+    def has__content(self):
         if (
             self.name is not None or
             self.interest or
@@ -1145,6 +1151,11 @@ class personType(GeneratedsSuper):
 # end class personType
 
 
+#
+# End data representation classes.
+#
+
+
 GDSClassesMapping = {
     'people': peopleType,
     'person': personType,
