@@ -3,7 +3,7 @@
 
 #
 # Generated  by generateDS.py.
-# Python 3.10.6 (main, Nov 14 2022, 16:10:14) [GCC 11.3.0]
+# Python 3.10.12 (main, Jun 11 2023, 05:26:28) [GCC 11.4.0]
 #
 # Command line options:
 #   ('--no-dates', '')
@@ -265,7 +265,11 @@ except ModulenotfoundExp_ as exp:
                     raise_parse_error(node, 'Requires sequence of integer values')
             return values
         def gds_format_float(self, input_data, input_name=''):
-            return ('%.15f' % float(input_data)).rstrip('0')
+            value = ('%.15f' % float(input_data)).rstrip('0')
+            if value.endswith('.'):
+                value += '0'
+            return value
+    
         def gds_parse_float(self, input_data, node=None, input_name=''):
             try:
                 fval_ = float(input_data)
@@ -1003,11 +1007,13 @@ def _cast(typ, value):
         return value
     return typ(value)
 
-#
-# Data representation classes.
-#
-
 
+#
+# Start enum classes
+#
+#
+# Start data representation classes
+#
 class authorsType(GeneratedsSuper):
     __hash__ = GeneratedsSuper.__hash__
     member_data_items_ = [
@@ -1067,7 +1073,7 @@ class authorsType(GeneratedsSuper):
         self.cooperation.insert(index, value)
     def replace_cooperation_at(self, index, value):
         self.cooperation[index] = value
-    def _hasContent(self):
+    def has__content(self):
         if (
             self.author or
             self.cooperation
@@ -1091,7 +1097,7 @@ class authorsType(GeneratedsSuper):
         outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
         already_processed = set()
         self._exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='authorsType')
-        if self._hasContent():
+        if self.has__content():
             outfile.write('>%s' % (eol_, ))
             self._exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='authorsType', pretty_print=pretty_print)
             showIndent(outfile, level, pretty_print)
@@ -1174,7 +1180,7 @@ class author(GeneratedsSuper):
         return self.description
     def set_description(self, description):
         self.description = description
-    def _hasContent(self):
+    def has__content(self):
         if (
             self.description is not None
         ):
@@ -1197,7 +1203,7 @@ class author(GeneratedsSuper):
         outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
         already_processed = set()
         self._exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='author')
-        if self._hasContent():
+        if self.has__content():
             outfile.write('>%s' % (eol_, ))
             self._exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='author', pretty_print=pretty_print)
             showIndent(outfile, level, pretty_print)
@@ -1238,6 +1244,11 @@ class author(GeneratedsSuper):
 # end class author
 
 
+#
+# End data representation classes.
+#
+
+
 GDSClassesMapping = {
     'authors': authorsType,
 }
