@@ -3,7 +3,7 @@
 
 #
 # Generated  by generateDS.py.
-# Python 3.10.6 (main, Nov 14 2022, 16:10:14) [GCC 11.3.0]
+# Python 3.10.12 (main, Jun 11 2023, 05:26:28) [GCC 11.4.0]
 #
 # Command line options:
 #   ('--no-dates', '')
@@ -265,7 +265,11 @@ except ModulenotfoundExp_ as exp:
                     raise_parse_error(node, 'Requires sequence of integer values')
             return values
         def gds_format_float(self, input_data, input_name=''):
-            return ('%.15f' % float(input_data)).rstrip('0')
+            value = ('%.15f' % float(input_data)).rstrip('0')
+            if value.endswith('.'):
+                value += '0'
+            return value
+    
         def gds_parse_float(self, input_data, node=None, input_name=''):
             try:
                 fval_ = float(input_data)
@@ -1003,11 +1007,13 @@ def _cast(typ, value):
         return value
     return typ(value)
 
-#
-# Data representation classes.
-#
-
 
+#
+# Start enum classes
+#
+#
+# Start data representation classes
+#
 class IdentifierType(GeneratedsSuper):
     __hash__ = GeneratedsSuper.__hash__
     member_data_items_ = [
@@ -1091,7 +1097,7 @@ class IdentifierType(GeneratedsSuper):
     def set_valueOf_(self, valueOf_): self.valueOf_ = valueOf_
     def get_extensiontype_(self): return self.extensiontype_
     def set_extensiontype_(self, extensiontype_): self.extensiontype_ = extensiontype_
-    def _hasContent(self):
+    def has__content(self):
         if (
             (1 if type(self.valueOf_) in [int,float] else self.valueOf_)
         ):
@@ -1232,10 +1238,10 @@ class BillOfResourcesIDType(IdentifierType):
         self.ns_prefix_ = ns_prefix
     def get_valueOf_(self): return self.valueOf_
     def set_valueOf_(self, valueOf_): self.valueOf_ = valueOf_
-    def _hasContent(self):
+    def has__content(self):
         if (
             (1 if type(self.valueOf_) in [int,float] else self.valueOf_) or
-            super(BillOfResourcesIDType, self)._hasContent()
+            super(BillOfResourcesIDType, self).has__content()
         ):
             return True
         else:
@@ -1316,10 +1322,10 @@ class BillOfMaterialIDType(IdentifierType):
         self.ns_prefix_ = ns_prefix
     def get_valueOf_(self): return self.valueOf_
     def set_valueOf_(self, valueOf_): self.valueOf_ = valueOf_
-    def _hasContent(self):
+    def has__content(self):
         if (
             (1 if type(self.valueOf_) in [int,float] else self.valueOf_) or
-            super(BillOfMaterialIDType, self)._hasContent()
+            super(BillOfMaterialIDType, self).has__content()
         ):
             return True
         else:
@@ -1368,6 +1374,11 @@ class BillOfMaterialIDType(IdentifierType):
 # end class BillOfMaterialIDType
 
 
+#
+# End data representation classes.
+#
+
+
 GDSClassesMapping = {
 }
 
