@@ -3,7 +3,7 @@
 
 #
 # Generated  by generateDS.py.
-# Python 3.10.6 (main, Nov 14 2022, 16:10:14) [GCC 11.3.0]
+# Python 3.10.12 (main, Jun 11 2023, 05:26:28) [GCC 11.4.0]
 #
 # Command line options:
 #   ('--no-dates', '')
@@ -264,7 +264,11 @@ except ModulenotfoundExp_ as exp:
                     raise_parse_error(node, 'Requires sequence of integer values')
             return values
         def gds_format_float(self, input_data, input_name=''):
-            return ('%.15f' % float(input_data)).rstrip('0')
+            value = ('%.15f' % float(input_data)).rstrip('0')
+            if value.endswith('.'):
+                value += '0'
+            return value
+    
         def gds_parse_float(self, input_data, node=None, input_name=''):
             try:
                 fval_ = float(input_data)
@@ -1002,11 +1006,13 @@ def _cast(typ, value):
         return value
     return typ(value)
 
-#
-# Data representation classes.
-#
-
 
+#
+# Start enum classes
+#
+#
+# Start data representation classes
+#
 class simpleTypeTestsType(GeneratedsSuper):
     __hash__ = GeneratedsSuper.__hash__
     member_data_items_ = [
@@ -1060,7 +1066,7 @@ class simpleTypeTestsType(GeneratedsSuper):
         return self.simpleContentTest
     def set_simpleContentTest(self, simpleContentTest):
         self.simpleContentTest = simpleContentTest
-    def _hasContent(self):
+    def has__content(self):
         if (
             self.simpleTypeTest or
             self.simpleContentTest is not None
@@ -1084,7 +1090,7 @@ class simpleTypeTestsType(GeneratedsSuper):
         outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
         already_processed = set()
         self._exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='simpleTypeTestsType')
-        if self._hasContent():
+        if self.has__content():
             outfile.write('>%s' % (eol_, ))
             self._exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='simpleTypeTestsType', pretty_print=pretty_print)
             showIndent(outfile, level, pretty_print)
@@ -1180,7 +1186,7 @@ class simpleContentType(GeneratedsSuper):
         self.identifier = identifier
     def get_valueOf_(self): return self.valueOf_
     def set_valueOf_(self, valueOf_): self.valueOf_ = valueOf_
-    def _hasContent(self):
+    def has__content(self):
         if (
             (1 if type(self.valueOf_) in [int,float] else self.valueOf_)
         ):
@@ -1496,7 +1502,7 @@ class simpleTypeTestDefs(GeneratedsSuper):
         self.dateTimeVal2.insert(index, value)
     def replace_dateTimeVal2_at(self, index, value):
         self.dateTimeVal2[index] = value
-    def _hasContent(self):
+    def has__content(self):
         if (
             self.datetime1 is not None or
             self.datetime2 is not None or
@@ -1539,7 +1545,7 @@ class simpleTypeTestDefs(GeneratedsSuper):
         outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
         already_processed = set()
         self._exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='simpleTypeTestDefs')
-        if self._hasContent():
+        if self.has__content():
             outfile.write('>%s' % (eol_, ))
             self._exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='simpleTypeTestDefs', pretty_print=pretty_print)
             showIndent(outfile, level, pretty_print)
@@ -1776,6 +1782,11 @@ class simpleTypeTestDefs(GeneratedsSuper):
 # end class simpleTypeTestDefs
 
 
+#
+# End data representation classes.
+#
+
+
 GDSClassesMapping = {
     'simpleTypeTests': simpleTypeTestsType,
 }
