@@ -13,6 +13,13 @@ examples:
 
 more info:
   https://lxml.de/validation.html
+
+notes:
+  This small app basically does the same validation that is done
+  by xmllint.  In fact, since this app is built on top of
+  lxml and since xmllint and lxml are both built
+  on top of libxml, it uses the same code to perform that
+  validation.
 """
 
 
